pub enum GetDisjointMutError {
IndexOutOfBounds,
OverlappingIndices,
}Expand description
The error type returned by get_disjoint_mut.
It indicates one of two possible errors:
- An index is out-of-bounds.
- The same index appeared multiple times in the array (or different but overlapping indices when ranges are provided).
Examples
Variants
IndexOutOfBounds
An index provided was out-of-bounds for the slice.
OverlappingIndices
Two indices provided were overlapping.